package com.mygdx.game;

import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.charset.StandardCharsets;

import org.usb4java.Device;

public class McuWithPeriBoardTest extends McuBoard
{
	private static final byte RQ_SET_LED       = 0;
    private static final byte RQ_SET_AL_VALUE = 1;
    private static final byte RQ_GET_SWITCH_SWORD    = 4;
    private static final byte RQ_GET_LIGHT     = 3;
    private static final byte RQ_GET_ALA     = 5;
    private static final byte RQ_GET_ALG     = 6;
    public static int ax ,ay ,az ,gx ,gy ,gz ;
    private static long[] pos_old = new long[3];
    private static long[] pos_new = new long[3];
    public static long distance = 0;
    //    private static final byte RQ_GET_ALX2     = 6;
//    private static final byte RQ_GET_ALY1     = 7;
//    private static final byte RQ_GET_ALY2     = 8;
//    private static final byte RQ_GET_ALZ1     = 9;
//    private static final byte RQ_GET_ALZ2     = 10;

    public McuWithPeriBoardTest(Device device) {
		super(device);
	}

    /**
     * Set status of LED on peripheral board
     * 
     * @param ledNo  the number of LED (0,1,2) to set status
     * @param value  status to set (0-off, 1-on)
     */
    public void setLed(int num, int value)
    {
        this.write(RQ_SET_LED, (short) num, (short) value);
    }

    /**
     * Display a binary value on the peripheral board's LEDs
     * 
     * @param value The value to be displayed on the LEDs
     */
    public void setALValue(int value)
    {
        this.write(RQ_SET_AL_VALUE, (short) 0, (short) (value));
    }

    /**
     * Check the state of the switch
     * 
     * @return true when the switch is pressed; false otherwise
     */
    public boolean getSwitch()
    {
        byte[] ret = this.read(RQ_GET_SWITCH_SWORD, (short) 0, (short) 0);
        return ret[0] == 1;
    }

    /**
     * Read and return the light intensity
     * 
     * @return a value between 0-1023; the greater the intensity, the higher the value
     */
    public int getLight()
    {
        byte[] ret = this.read(RQ_GET_LIGHT, (short) 0, (short) 0);
        return (ret[0] & 0xFF) + (ret[1] & 0xFF)*256;
    }
    
    public void getAccelerationA(){
    	try{
    	byte[] ret = this.read(RQ_GET_ALA, (short) 0, (short) 0);
//    	System.out.println(ret.length);
    	
    	pos_old[0] = pos_new[0];
    	pos_old[1] = pos_new[1];
    	pos_old[2] = pos_new[2];
    	
    	 ax = ByteBuffer.wrap(ret,0,2).order(ByteOrder.LITTLE_ENDIAN).getShort();
    	 ay = ByteBuffer.wrap(ret,2,2).order(ByteOrder.LITTLE_ENDIAN).getShort();
    	 az = ByteBuffer.wrap(ret,4,2).order(ByteOrder.LITTLE_ENDIAN).getShort();
 //   	 gx = ByteBuffer.wrap(ret,6,2).order(ByteOrder.LITTLE_ENDIAN).getShort(); 
 //   	 gy = ByteBuffer.wrap(ret,8,2).order(ByteOrder.LITTLE_ENDIAN).getShort();
 //   	 gz = ByteBuffer.wrap(ret,10,2).order(ByteOrder.LITTLE_ENDIAN).getShort();
    	 
    	 pos_new[0] = ax;
    	 pos_new[1] = ay;
    	 pos_new[2] = az;
    	 
    	 long dx = pos_new[0] - pos_old[0];
    	 long dy = pos_new[1] - pos_old[1];
    	 long dz = pos_new[2] - pos_old[2];
    	 
//    	 pos_new = (long)Math.pow(Math.pow(ax, 2) + Math.pow(ay, 2) + Math.pow(az, 2), 0.5);
    	 
    	 distance = (long)Math.pow(Math.pow(dx, 2) + Math.pow(dy, 2) + Math.pow(dz, 2), 0.5);
    	 
//    	 System.out.println(ax +" ");
//    	 System.out.println(ay + " ");
//    	 System.out.println(az + " ");
    	 
//    	 System.out.println(distance + " ");
    	
//    	 System.out.println(gx + " ");
//    	 System.out.println(gy + " ");
//    	 System.out.println(gz + "\n");
 //   	System.out.println(ret);((uint8_t)(ax >> 8)); Serial.write((uint8_t)(ax & 0xFF))
 //   	return (ret[0] & 0xFF) + (ret[1] & 0xFF)*256;
    	}catch(Exception e){
    		System.out.println(e);
    	}
    }
    
    public void getAccelerationG(){
    	byte[] ret = this.read(RQ_GET_ALG, (short) 0, (short) 0);
//    	System.out.println(ret.length);
    	 gx = ByteBuffer.wrap(ret,0,2).order(ByteOrder.LITTLE_ENDIAN).getShort(); 
    	 gy = ByteBuffer.wrap(ret,2,2).order(ByteOrder.LITTLE_ENDIAN).getShort();
    	 gz = ByteBuffer.wrap(ret,4,2).order(ByteOrder.LITTLE_ENDIAN).getShort();
    	 
//    	 System.out.println(gx + " ");
//    	 System.out.println(gy + " ");
//    	 System.out.println(gz + "\n");
 //   	System.out.println(ret);((uint8_t)(ax >> 8)); Serial.write((uint8_t)(ax & 0xFF))
 //   	return (ret[0] & 0xFF) + (ret[1] & 0xFF)*256;
    }
    
    public long getDistance(){
    	return distance;
    }
    
//    public int getAccelerationX2(){
//    	byte[] ret = this.read(RQ_GET_ALX2, (short) 0, (short) 0);
// //   	System.out.println(ret);((uint8_t)(ax >> 8)); Serial.write((uint8_t)(ax & 0xFF))
//    	return ((ret[0] & 0xFF) + (ret[1] & 0xFF)*256);
//    }
    
//    public int getAccelerationY(){
//    	byte[] ret = this.read(RQ_GET_ALY1, (short) 0, (short) 0);
//  //  	System.out.println(ret);
//    	return ((ret[0] & 0xFF) + (ret[1] & 0xFF)*256);
//    }
//    
//    public int getAccelerationZ(){
//    	byte[] ret = this.read(RQ_GET_ALZ1, (short) 0, (short) 0);
////    	System.out.println(ret);
//    	return (ret[0] & 0xFF) + (ret[1] & 0xFF)*256;
//    }
}
