#include "I2Cdev.h"
#include "MPU6050.h"
MPU6050 accelgyro;

#include <usbdrv.h>
#include <Wire.h>

#define RQ_SET_AL_VALUE 1
#define RQ_GET_SWITCH_SWORD 4
#define RQ_GET_ALA 5
#define RQ_GET_ALG 6
#define RQ_GET_ALZ 7

struct MotionA {
  int16_t ax, ay, az;
};

struct MotionG {
  int16_t gx, gy, gz;
};

MotionA motionAData;
MotionG motionGData;

unsigned char Re_buf[8];
//////////////////////////////////////////////////////////////////////
usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
  usbRequest_t *rq = (usbRequest_t*)data;
  static uint8_t switch_state;

  if (rq->bRequest == RQ_GET_SWITCH_SWORD)
  {
    if (digitalRead(PIN_PB0) == LOW) /* switch is pressed */
      switch_state = 1;
    else
      switch_state = 0;

    /* point usbMsgPtr to the data to be returned to host */
    usbMsgPtr = (uint8_t*) &switch_state;

    /* return the number of bytes of data to be returned to host */
    return sizeof(switch_state);
  }

  else if (rq->bRequest == RQ_GET_ALA) {
    accelgyro.getAcceleration(&motionAData.ax, &motionAData.ay, &motionAData.az);
//        accelgyro.getMotion6(&motionData.ax, &motionData.ay, &motionData.az,
//                             &motionData.gx, &motionData.gy, &motionData.gz);
    usbMsgPtr = (uint8_t*) &motionAData;
    return sizeof(motionAData);
  }

  else if (rq->bRequest == RQ_GET_ALG) {
    accelgyro.getRotation(&motionGData.gx, &motionGData.gy, &motionGData.gz);
    usbMsgPtr = (uint8_t*) &motionGData;
    return sizeof(motionGData);
  }

if (rq->bRequest == RQ_SET_AL_VALUE)
  {
    uint8_t AL_status = rq->wValue.bytes[0];
    uint8_t AL_location  = rq->wIndex.bytes[0];

    if (AL_location == 0)
      digitalWrite(PIN_PC0, AL_status);

    return 0;  // return no data back to host
  }
  
  return 0;   /* nothing to do; return no data back to host */
}

//////////////////////////////////////////////////////////////////////
void setup()
{

    pinMode(PIN_PB0, INPUT);
    pinMode(PIN_PC0, OUTPUT);
  //  pinMode(PIN_PC5, INPUT);
  //  //    pinMode(PIN_PC6,INPUT);
  //  pinMode(PIN_PD3, OUTPUT);
  //
#if I2CDEV_IMPLEMENTATION == I2CDEV_ARDUINO_WIRE
  Wire.begin();
#elif I2CDEV_IMPLEMENTATION == I2CDEV_BUILTIN_FASTWIRE
  Fastwire::setup(400, true);
#endif
  accelgyro.initialize();

  usbInit();

  /* enforce re-enumeration of USB devices */
  usbDeviceDisconnect();
  delay(300);
  usbDeviceConnect();
  digitalWrite(PIN_PC0, 0);
}

//////////////////////////////////////////////////////////////////////
void loop()
{
  usbPoll();
}

//////////////////////////////////////////////////////////////////////
